==> firebase_storage_platform_interface-1.0.0-dev.1.tar.gz: test/method_channel_tests/method_channel_list_result_test.dart <==
// Copyright 2020, the Chromium project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'package:firebase_core/firebase_core.dart';
import 'package:firebase_storage_platform_interface/src/method_channel/method_channel_list_result.dart';
import 'package:flutter_test/flutter_test.dart';

import 'package:firebase_storage_platform_interface/firebase_storage_platform_interface.dart';
import 'package:firebase_storage_platform_interface/src/method_channel/method_channel_firebase_storage.dart';
import '../mock.dart';

void main() {
  setupFirebaseStorageMocks();

  MethodChannelListResult testListResult;

  group('$MethodChannelListResult', () {
    setUpAll(() async {
      FirebaseApp app = await Firebase.initializeApp();
      FirebaseStoragePlatform storage = MethodChannelFirebaseStorage(app: app);
      testListResult = MethodChannelListResult(
        storage,
        nextPageToken: '123',
        items: ['foo', 'bar'],
        prefixes: ['foo', 'bar'],
      );
    });

    group('items', () {
      test('should return successfully', () {
        final result = testListResult.items;
        expect(result, isInstanceOf<List<ReferencePlatform>>());
        expect(result.length, equals(2));
      });
    });

    group('prefixes', () {
      test('should return successfully', () {
        final result = testListResult.prefixes;
        expect(result, isInstanceOf<List<ReferencePlatform>>());
        expect(result.length, equals(2));
      });
    });
  });
}

==> firebase_storage_platform_interface-1.0.4.tar.gz: test/method_channel_tests/method_channel_list_result_test.dart <==
// Copyright 2020, the Chromium project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'package:firebase_core/firebase_core.dart';
import 'package:firebase_storage_platform_interface/src/method_channel/method_channel_list_result.dart';
import 'package:flutter_test/flutter_test.dart';

import 'package:firebase_storage_platform_interface/firebase_storage_platform_interface.dart';
import 'package:firebase_storage_platform_interface/src/method_channel/method_channel_firebase_storage.dart';
import '../mock.dart';

void main() {
  setupFirebaseStorageMocks();

  /*late*/ MethodChannelListResult testListResult;

  group('$MethodChannelListResult', () {
    setUpAll(() async {
      FirebaseApp app = await Firebase.initializeApp();
      FirebaseStoragePlatform storage = MethodChannelFirebaseStorage(app: app);
      testListResult = MethodChannelListResult(
        storage,
        nextPageToken: '123',
        items: ['foo', 'bar'],
        prefixes: ['foo', 'bar'],
      );
    });

    group('items', () {
      test('should return successfully', () {
        final result = testListResult.items;
        expect(result, isInstanceOf<List<ReferencePlatform>>());
        expect(result.length, equals(2));
      });
    });

    group('prefixes', () {
      test('should return successfully', () {
        final result = testListResult.prefixes;
        expect(result, isInstanceOf<List<ReferencePlatform>>());
        expect(result.length, equals(2));
      });
    });
  });
}
